Learn R Programming

CCWeights (version 0.1.6)

doEvaluation: Evaluate Different Weighting Factors

Description

Evaluate different weighting factors.

Usage

doEvaluation(DF, p = 0.05, userWeights = NULL)

Arguments

DF

data frame, it must contain a column named 'Concentration' and a column named 'Response'

p

p-value, default is 0.05

userWeights

user defined weights in linear regression, default is NULL. User can easily define weights, e.g., "1/x", "1/x^2", "1/y"

Value

dataframe, weighting factor evaluation result

Examples

Run this code
# NOT RUN {
Concentration <- rep(c(10, 50, 100, 500), each = 3)
Response <- c(133, 156, 177, 1300, 1450, 1600, 4000, 3881, 3700, 140000, 139000, 140000)
DF <- cbind.data.frame(Concentration = Concentration, Response = Response)
result <- doEvaluation(DF)
# }

Run the code above in your browser using DataLab